//
//  CGColorHolder.m
//
//  Created by Bill Dudney on 2/27/08.
//
// Copyright 2008 Gala Factory
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#import "CGColorHolder.h"

@interface CGColorHolder(Private)
+ (CGColorRef)colorWithRed:(CGFloat)red green:(CGFloat)green blue:(CGFloat)blue alpha:(CGFloat)alpha;
@end

@implementation CGColorHolder

+ (CGColorSpaceRef)genericRGBSpace {
  static CGColorSpaceRef space = NULL;
  if(NULL == space) {
    space = CGColorSpaceCreateWithName (kCGColorSpaceGenericRGB);
  }
  return space;
}

+ (CGColorRef)clear {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:0.0f green:0.0f blue:0.0f alpha:0.0f];
  }
  return color;
}

+ (CGColorRef)white {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:1.0f green:1.0f blue:1.0f alpha:1.0f];
  }
  return color;
}

+ (CGColorRef)black {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:0.0f green:0.0f blue:0.0f alpha:1.0f];
  }
  return color;
}

+ (CGColorRef)red {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:1.0f green:0.0f blue:0.0f alpha:1.0f];
  }
  return color;
}

+ (CGColorRef)blue {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:0.0f green:0.0f blue:1.0f alpha:1.0f];
  }
  return color;
}

+ (CGColorRef)halfRed {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:1.0f green:0.0f blue:0.0f alpha:0.5f];
  }
  return color;
}  
+ (CGColorRef)halfBlue {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:0.0f green:0.0f blue:1.0f alpha:0.5f];
  }
  return color;
}

+ (CGColorRef)halfWhite {
  static CGColorRef color = NULL;
  if(color == NULL) {
    color = [self colorWithRed:1.0f green:1.0f blue:1.0f alpha:0.5f];
  }
  return color;
}

@end

@implementation CGColorHolder(Private)

+ (CGColorRef)colorWithRed:(CGFloat)red green:(CGFloat)green blue:(CGFloat)blue alpha:(CGFloat)alpha {
  CGFloat values[4] = {red, green, blue, alpha};
  return CGColorCreate([self genericRGBSpace], values);
}

@end

